import 'package:flutter/material.dart';
import 'package:path_stack/path_stack.dart';

import 'advanced_tab_example_pages.dart';

class AppPaths {
  static const String tabsCategory = "tabs/";
}

/// Root level path-stack, a tabbed scaffold with 2 levels of nesting.
class AdvancedTabExample extends StatefulWidget {
  @override
  _AdvancedTabExampleState createState() => _AdvancedTabExampleState();
}

// A simple value listener, that holds a path, driving the state of the entire application.
ValueNotifier<String> pathNotifier = ValueNotifier(AppPaths.tabsCategory + HomePage.path);

class _AdvancedTabExampleState extends State<AdvancedTabExample> {
  @override
  Widget build(BuildContext context) {
    return ValueListenableBuilder<String>(
      valueListenable: pathNotifier,
      builder: (_, currentPath, __) {
        return PathStack(
          path: currentPath,
          routes: {
            // /tabs/
            [AppPaths.tabsCategory]: (_) => PathStack(
                  // Main scaffold is wrapped here
                  scaffoldBuilder: (_, stack) => MainScaffold(child: stack),
                  transitionBuilder: (_, stack, animation) => FadeTransition(opacity: animation, child: stack),
                  routes: {
                    // /tabs/home
                    [HomePage.path]: (_) => HomePage(""),
                    // /tabs/settings/
                    [SettingsHome.path]: (_) => PathStack(
                          // A 2nd scaffold is wrapped here
                          scaffoldBuilder: (_, child) => SettingsScaffold(child: child),
                          routes: {
                            // /tabs/settings/profile
                            [ProfileSettings.path]: (_) => ProfileSettings(""),
                            // /tabs/settings/alert
                            [AlertSettings.path]: (_) => AlertSettings(""),
                            // /tabs/settings/billing
                            [BillingSettings.path]: (_) =>
                                RouteConfig(maintainState: false, exactMatch: false, child: BillingSettings(""))
                          },
                        ),
                  },
                ),
          },
        );
      },
    );
  }
}
