import 'package:flutter/material.dart';

import 'advanced_tab_example.dart';

class MainScaffold extends StatefulWidget {
  final Widget child;

  const MainScaffold({Key? key, required this.child}) : super(key: key);

  @override
  _MainScaffoldState createState() => _MainScaffoldState();
}

class _MainScaffoldState extends State<MainScaffold> {
  int buildCount = 0;
  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Padding(
          padding: const EdgeInsets.all(8.0).copyWith(top: 40),
          child: Column(
            children: [
              // pretend url bar
              Container(
                padding: EdgeInsets.all(12),
                color: Colors.grey.shade200,
                width: double.infinity,
                child: Text("https://myflutterapp/${pathNotifier.value}",
                    style: TextStyle(fontSize: 16, fontWeight: FontWeight.w600)),
              ),
              Expanded(child: widget.child),
              Row(children: [
                _UrlBtn("home", url: AppPaths.tabsCategory + HomePage.path),
                _UrlBtn("settings",
                    url: AppPaths.tabsCategory + SettingsHome.path + ProfileSettings.path,
                    alias: AppPaths.tabsCategory + SettingsHome.path),
              ]),
            ],
          ),
        ),
      ],
    );
  }
}

class SettingsScaffold extends StatefulWidget {
  final Widget child;

  const SettingsScaffold({Key? key, required this.child}) : super(key: key);

  @override
  _SettingsScaffoldState createState() => _SettingsScaffoldState();
}

class _SettingsScaffoldState extends State<SettingsScaffold> {
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Column(children: [
        Row(
          children: [
            _UrlBtn("profile", url: "${AppPaths.tabsCategory}${SettingsHome.path}${ProfileSettings.path}"),
            _UrlBtn("alerts", url: "${AppPaths.tabsCategory}${SettingsHome.path}${AlertSettings.path}"),
            _UrlBtn("Billing", url: "${AppPaths.tabsCategory}${SettingsHome.path}${BillingSettings.path}"),
          ],
        ),
        Expanded(child: widget.child),
      ]),
    );
  }
}

class _UrlBtn extends StatelessWidget {
  final String url;
  final String? alias;
  final String label;

  const _UrlBtn(this.label, {Key? key, required this.url, this.alias}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    bool isSelected = pathNotifier.value.contains(alias ?? url);
    TextStyle textStyle = TextStyle(fontSize: 22, color: isSelected ? Colors.black : Colors.blue);
    return Expanded(
      child: OutlinedButton(
          onPressed: () {
            pathNotifier.value = url;
          },
          child: Padding(padding: EdgeInsets.symmetric(vertical: 10), child: Text(label, style: textStyle))),
    );
  }
}

class SomeStatefulPage extends StatefulWidget {
  SomeStatefulPage(String title, {Key? key}) : super(key: key) {
    this.title = title;
    print("${this} TITLE = $title");
  }
  late final String title;

  @override
  _SomeStatefulPageState createState() => _SomeStatefulPageState();
}

class _SomeStatefulPageState extends State<SomeStatefulPage> {
  List<int>? items;
  TextEditingController txtController = TextEditingController();
  @override
  void initState() {
    super.initState();
    Future.delayed(Duration(seconds: 1), () {
      if (mounted == false) return;
      setState(() => items = List.generate(100, (index) => index));
    });
  }

  @override
  Widget build(BuildContext context) {
    if (items == null) return Center(child: CircularProgressIndicator());
    return Column(
      children: [
        Row(
          children: [
            Text(widget.title, style: TextStyle(fontSize: 22)),
            Spacer(),
            Text("Search Filter:", style: TextStyle(fontSize: 16)),
            Expanded(
                child: Padding(
              padding: const EdgeInsets.all(8.0),
              child: TextFormField(
                decoration: InputDecoration(border: OutlineInputBorder()),
              ),
            )),
          ],
        ),
        Expanded(
            child: ListView.builder(
                itemBuilder: (_, index) => Container(
                      width: double.infinity,
                      padding: const EdgeInsets.all(8.0),
                      color: (index % 2 == 0 ? Colors.grey : Colors.white).withOpacity(.1),
                      child: Text("ITEM: $index"),
                    ))),
      ],
    );
  }
}

class HomePage extends SomeStatefulPage {
  static const String path = "home";
  HomePage(String suffix) : super("Home Page, $suffix");
}

class SettingsHome extends SomeStatefulPage {
  static const String path = "settings/";
  SettingsHome(String suffix) : super("Settings Home, $suffix");
}

class ProfileSettings extends SomeStatefulPage {
  static const String path = "profile";
  ProfileSettings(String suffix) : super("Profile Settings, $suffix");
}

class AlertSettings extends SomeStatefulPage {
  static const String path = "alerts";
  AlertSettings(String suffix) : super("Alert Settings, $suffix");
}

class BillingSettings extends SomeStatefulPage {
  static const String path = "billing";
  BillingSettings(String suffix) : super("Billing Settings, $suffix");
}
